@@ -32,6 +32,7 @@ import time
 import re
 import getpass
 import gettext
+import re
 import types
 import urllib
 import urlparse
@@ -71,17 +72,9 @@ _backend_prefixes = {}
 # This looks similar to urlparse's 'uses_netloc' list, but urlparse doesn't use
 # that list for parsing, only creating urls.  And doesn't include our custom
 # schemes anyway.  So we keep our own here for our own use.
-uses_netloc = ['ftp',
-               'ftps',
-               'hsi',
-               's3',
-               'scp', 'ssh', 'sftp',
-               'webdav', 'webdavs',
-               'gdocs',
-               'http', 'https',
-               'imap', 'imaps',
-               'mega',
-               'copy']
+#
+# NOTE: this is filled by the respective backends during registering
+uses_netloc = []
 
 
 def import_backends():
@@ -104,11 +97,9 @@ def import_backends():
             try:
                 __import__(imp)
                 res = "Succeeded"
-                level = log.INFO
             except Exception:
                 res = "Failed: " + str(sys.exc_info()[1])
-                level = log.WARNING
-            log.Log(_("Import of %s %s") % (imp, res), level)
+            log.Log(_("Import of %s %s") % (imp, res), log.INFO)
         else:
             continue
 
@@ -164,6 +155,11 @@ def register_backend_prefix(scheme, backend_factory):
 
     _backend_prefixes[scheme] = backend_factory
 
+def strip_prefix(url_string, prefix_scheme):
+    """
+    strip the prefix from a string e.g. par2+ftp://... -> ftp://...
+    """
+    return re.sub('(?i)^' + re.escape(prefix_scheme) + '\+', '', url_string)
 
 def is_backend_url(url_string):
     """
@@ -198,11 +194,11 @@ def get_backend_object(url_string):
     for prefix in _backend_prefixes:
         if url_string.startswith(prefix + '+'):
             factory = _backend_prefixes[prefix]
-            pu = ParsedUrl(url_string.lstrip(prefix + '+'))
+            pu = ParsedUrl(strip_prefix(url_string, prefix))
             break
 
     if factory is None:
-        if not pu.scheme in _backends:
+        if pu.scheme not in _backends:
             raise UnsupportedBackendScheme(url_string)
         else:
             factory = _backends[pu.scheme]
@@ -298,10 +294,10 @@ class ParsedUrl:
         self.port = None
         try:
             self.port = pu.port
-        except Exception: # not raised in python2.7+, just returns None
+        except Exception:  # not raised in python2.7+, just returns None
             # old style rsync://host::[/]dest, are still valid, though they contain no port
-            if not ( self.scheme in ['rsync'] and re.search('::[^:]*$', self.url_string)):
-                raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" % (url_string, (self.scheme in ['rsync']), re.search('::[^:]+$', self.netloc), self.netloc ) )
+            if not (self.scheme in ['rsync'] and re.search('::[^:]*$', self.url_string)):
+                raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" % (url_string, (self.scheme in ['rsync']), re.search('::[^:]+$', self.netloc), self.netloc))
 
         # Our URL system uses two slashes more than urlparse's does when using
         # non-netloc URLs.  And we want to make sure that if urlparse assuming
@@ -337,11 +333,8 @@ class ParsedUrl:
 def strip_auth_from_url(parsed_url):
     """Return a URL from a urlparse object without a username or password."""
 
-    # Get a copy of the network location without the username or password.
-    straight_netloc = parsed_url.netloc.split('@')[-1]
-
-    # Replace the full network location with the stripped copy.
-    return parsed_url.geturl().replace(parsed_url.netloc, straight_netloc, 1)
+    clean_url = re.sub('^([^:/]+://)(.*@)?(.*)', r'\1\3', parsed_url.geturl())
+    return clean_url
 
 def _get_code_from_exception(backend, operation, e):
     if isinstance(e, BackendException) and e.code != log.ErrorCode.backend_error:
@@ -394,9 +387,9 @@ def retry(operation, fatal=True):
                                  % (n, e.__class__.__name__, util.uexc(e)))
                     if not at_end:
                         if isinstance(e, TemporaryLoadException):
-                            time.sleep(90) # wait longer before trying again
+                            time.sleep(90)  # wait longer before trying again
                         else:
-                            time.sleep(30) # wait a bit before trying again
+                            time.sleep(30)  # wait a bit before trying again
                         if hasattr(self.backend, '_retry_cleanup'):
                             self.backend._retry_cleanup()
 
@@ -428,8 +421,8 @@ class Backend(object):
             password = os.environ['FTP_PASSWORD']
         except KeyError:
             if self.use_getpass:
-                password = getpass.getpass("Password for '%s@%s': " %
-                                           (self.parsed_url.username,self.parsed_url.hostname) )
+                password = getpass.getpass("Password for '%s@%s': " % 
+                                           (self.parsed_url.username, self.parsed_url.hostname))
                 os.environ['FTP_PASSWORD'] = password
             else:
                 password = None
@@ -445,7 +438,7 @@ class Backend(object):
         the ':password@' may be substituted.
         """
         if self.parsed_url.password:
-            return re.sub( r'(:([^\s:/@]+)@([^\s@]+))', r':*****@\3', commandline )
+            return re.sub(r'(:([^\s:/@]+)@([^\s@]+))', r':*****@\3', commandline)
         else:
             return commandline
 
@@ -484,7 +477,7 @@ class Backend(object):
                 """ ignore a predefined set of error codes """
                 return 0, '', ''
             except (KeyError, ValueError):
-                raise BackendException("Error running '%s': returned %d, with output:\n%s" %
+                raise BackendException("Error running '%s': returned %d, with output:\n%s" % 
                                        (private, result, stdout + '\n' + stderr))
         return result, stdout, stderr
 
@@ -494,7 +487,7 @@ class BackendWrapper(object):
     Represents a generic duplicity backend, capable of storing and
     retrieving files.
     """
-    
+
     def __init__(self, backend):
         self.backend = backend
 
@@ -636,7 +629,7 @@ class BackendWrapper(object):
         except Exception as e:
             code = _get_code_from_exception(self.backend, 'query', e)
             if code == log.ErrorCode.backend_not_found:
-                return {'size': -1}
+                return {'size':-1}
             else:
                 raise e
 
@@ -648,7 +641,7 @@ class BackendWrapper(object):
         if hasattr(self.backend, '_close'):
             self.backend._close()
 
-    def get_fileobj_read(self, filename, parseresults = None):
+    def get_fileobj_read(self, filename, parseresults=None):
         """
         Return fileobject opened for reading of filename on backend
 
@@ -663,7 +656,7 @@ class BackendWrapper(object):
         tdp.setdata()
         return tdp.filtered_open_with_delete("rb")
 
-    def get_data(self, filename, parseresults = None):
+    def get_data(self, filename, parseresults=None):
         """
         Retrieve a file from backend, process it, return contents.
         """
