@@ -181,7 +181,10 @@ class BotoBackend(duplicity.backend.Backend):
         del self.storage_uri
         self.storage_uri = boto.storage_uri(self.boto_uri_str)
         self.conn = get_connection(self.scheme, self.parsed_url, self.storage_uri)
-        self.bucket = self.conn.lookup(self.bucket_name)
+        try:
+            self.bucket = self.conn.get_bucket(self.bucket_name)
+        except Exception as err:
+            raise BackendException(err.message)
 
     def _retry_cleanup(self):
         self.resetConnection()
@@ -225,12 +228,12 @@ class BotoBackend(duplicity.backend.Backend):
             'Content-Type': 'application/octet-stream',
             'x-amz-storage-class': storage_class
         }
-        
+
         upload_start = time.time()
         self.upload(source_path.name, key, headers)
         upload_end = time.time()
-        total_s = abs(upload_end-upload_start) or 1  # prevent a zero value!
-        rough_upload_speed = os.path.getsize(source_path.name)/total_s
+        total_s = abs(upload_end - upload_start) or 1  # prevent a zero value!
+        rough_upload_speed = os.path.getsize(source_path.name) / total_s
         log.Debug("Uploaded %s/%s to %s Storage at roughly %f bytes/second" % (self.straight_url, remote_filename, storage_class, rough_upload_speed))
 
     def _get(self, remote_filename, local_path):
@@ -254,7 +257,7 @@ class BotoBackend(duplicity.backend.Backend):
         #   AssertionError: Got list: []
         #   Wanted: ['testfile']
         # Because of the need for this optimization, it should be left as is.
-        #for k in self.bucket.list(prefix = self.key_prefix + 'd', delimiter = '/'):
+        # for k in self.bucket.list(prefix = self.key_prefix + 'd', delimiter = '/'):
         filename_list = []
         for k in self.bucket.list(prefix=self.key_prefix, delimiter='/'):
             try:
@@ -272,7 +275,7 @@ class BotoBackend(duplicity.backend.Backend):
     def _query(self, filename):
         key = self.bucket.lookup(self.key_prefix + filename)
         if key is None:
-            return {'size': -1}
+            return {'size':-1}
         return {'size': key.size}
 
     def upload(self, filename, key, headers):
