@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.0"
+version = "0.7.01"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -231,15 +231,9 @@ sftp_command = None
 # default to batch mode using public-key encryption
 ssh_askpass = False
 
-# default ssh backend is paramiko
-ssh_backend = "paramiko"
-
 # user added ssh options
 ssh_options = ""
 
-# whether to use scp for put/get, sftp is default
-use_scp = False
-
 # default cf backend is pyrax
 cf_backend = "pyrax"
 
