@@ -19,6 +19,7 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import os
+import sys
 import subprocess
 import unittest
 
@@ -27,14 +28,16 @@ from . import _top_dir, DuplicityTestCase
 
 class CodeTest(DuplicityTestCase):
 
-    def run_checker(self, cmd):
+    def run_checker(self, cmd, returncodes=[0]):
         process = subprocess.Popen(cmd,
                                    stdout=subprocess.PIPE,
                                    stderr=subprocess.PIPE)
         output = process.communicate()[0]
-        self.assertEqual(0, process.returncode, output)
+        self.assertTrue(process.returncode in returncodes, output)
         self.assertEqual("", output, output)
 
+    @unittest.skipUnless(os.getenv('RUN_CODE_TESTS', None) == '1',
+                         'Must set environment var RUN_CODE_TESTS=1')
     def test_2to3(self):
         # As we modernize the source code, we can remove more and more nofixes
         self.run_checker(["2to3",
@@ -54,6 +57,8 @@ class CodeTest(DuplicityTestCase):
                           "--nofix=xrange",
                           _top_dir])
 
+    @unittest.skipUnless(os.getenv('RUN_CODE_TESTS', None) == '1',
+                         'Must set environment var RUN_CODE_TESTS=1')
     def test_pylint(self):
         self.run_checker(["pylint",
                           "-E",
@@ -66,8 +71,13 @@ class CodeTest(DuplicityTestCase):
                           "--ignore=_librsync.so",
                           os.path.join(_top_dir, 'duplicity'),
                           os.path.join(_top_dir, 'bin/duplicity'),
-                          os.path.join(_top_dir, 'bin/rdiffdir')])
+                          os.path.join(_top_dir, 'bin/rdiffdir')],
+                         # Allow usage errors, older versions don't have
+                         # --msg-template
+                         [0, 32])
 
+    @unittest.skipUnless(os.getenv('RUN_CODE_TESTS', None) == '1',
+                         'Must set environment var RUN_CODE_TESTS=1')
     def test_pep8(self):
         # All these ignores are just because when this test was added, I didn't
         # want to fix all of the code.  Over time we can remove some of these
@@ -84,12 +94,6 @@ class CodeTest(DuplicityTestCase):
                    "E201",
                    "E202",
                    "E203",
-                   "E211",
-                   "E221",
-                   "E222",
-                   "E225",
-                   "E226",
-                   "E228",
                    "E231",
                    "E241",
                    "E251",
